Package: rneos
Version: 0.4-1
Date: 2026-01-24
Title: XML-RPC Interface to NEOS
Authors@R: c(person(given = "Bernhard", family = "Pfaff", email = "bernhard@pfaffikus.de", role = c("aut", "cre")), person(given = "Duncan Temple", family = "Lang", email = "<duncan@wald.ucdavis.edu", role = "ctb", comment = "included XMLRPC package, hosted at http://www.omegahat.net/XMLRPC/; BSD license."))
Depends: R (>= 2.10.0), methods, RCurl, XML, stats
LazyLoad: yes
Description: Within this package the XML-RPC API to NEOS <https://neos-server.org/neos/> is implemented. This enables the user to pass optimization problems to NEOS and retrieve results within R.
License: GPL (>= 2)
Maintainer: Bernhard Pfaff <bernhard@pfaffikus.de>
Repository: CRAN
Repository/R-Forge/Project: rneos
Repository/R-Forge/Revision: 249
Repository/R-Forge/DateTimeStamp: 2016-03-02 22:39:48
Date/Publication: 2026-01-25 06:10:13 UTC
NeedsCompilation: no
Packaged: 2026-01-24 15:34:34 UTC; bp
Author: Bernhard Pfaff [aut, cre],
  Duncan Temple Lang [ctb] (included XMLRPC package, hosted at
    http://www.omegahat.net/XMLRPC/; BSD license.)
Built: R 4.6.0; ; 2026-04-27 09:28:04 UTC; unix
